@@ -21,22 +21,38 @@ def test_resampling():
     x_new = (x_new_edges[1:] + x_new_edges[:-1]) / 2
 
     a = resample_while_conserving_flux(xin=x, yin=y, xout=x_new, visualize=True)
-    plt.savefig(os.path.join(resample_directory, "resampling-demonstration-a.pdf"))
+    plt.savefig(
+        os.path.join(
+            resample_directory, "demonstration-of-resampling-centers-in-centers-out.pdf"
+        )
+    )
 
     b = resample_while_conserving_flux(
         yin=y, xout=x_new, xin_edges=x_edges, visualize=True
     )
-    plt.savefig(os.path.join(resample_directory, "resampling-demonstration-b.pdf"))
+    plt.savefig(
+        os.path.join(
+            resample_directory, "demonstration-of-resampling-edges-in-centers-out.pdf"
+        )
+    )
 
     c = resample_while_conserving_flux(
         yin=y, xin_edges=x_edges, xout_edges=x_new_edges, visualize=True
     )
-    plt.savefig(os.path.join(resample_directory, "resampling-demonstration-c.pdf"))
+    plt.savefig(
+        os.path.join(
+            resample_directory, "demonstration-of-resampling-edges-in-edges-out.pdf"
+        )
+    )
 
     d = resample_while_conserving_flux(
         yin=y, xin=x, xout_edges=x_new_edges, visualize=True
     )
-    plt.savefig(os.path.join(resample_directory, "resampling-demonstration-d.pdf"))
+    plt.savefig(
+        os.path.join(
+            resample_directory, "demonstration-of-resampling-centers-in-edges-out.pdf"
+        )
+    )
 
     for x in [b, c, d]:
         assert np.isclose(np.sum(a["y"]), np.sum(x["y"]))
@@ -54,8 +70,9 @@ def test_bintogrid(N_original=23):
 
     def save_binning_example_figure():
         f = plt.gca().get_title()
-        f = f.replace(" ", "") + ".pdf"
+        f = "demonstration-of-" + f.replace(" ", "") + ".pdf"
         f = f.replace("$\sigma$", "uncertainty")
+        f = f.replace(",", "-")
         plt.savefig(os.path.join(bin_directory, f))
 
     for input_grid in ["uniform", "irregular"]:
@@ -98,7 +115,7 @@ def test_bintogrid(N_original=23):
                 save_binning_example_figure()
                 assert np.all(np.isclose(a["y"], c["y"]))
 
-            label = f"{input_grid} input grid, {uncertainties} $\sigma$"
+            label = f"{input_grid} input grid, {uncertainties} " + r"$\sigma$"
 
             # does binning to self give self?
             d = bintogrid(x, y, unc=u, newx=x, visualize=True)
